/* dsm1_c subroutine
 * First order Delta-Sigma Modulator
 * IRCOM GROUP - Author : A.Layec
 *
 * Copyright (C) 2007 Alan Layec
 *
 * This file is part of modnumlib.
 *
 * modnumlib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * modnumlib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with modnumlib; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

/* REVISION HISTORY :
 * $Log$
 */

#include "modnum_lib.h"

/* dsm1_c routine de calcul d'un modulateur sigma-delta du 1er ordre
 *
 * entres :
 * n   : longueur du vecteur d'entre (scalaire)
 * m   : gain du modulateur (scalaire)
 * u   : adresse de dpart du vecteur  convertir 
 * entres/sorties 
 * e   : intgral du signal d'erreur du dernier lment (scalaire)
 * z   : etat de sortie du dernier lment +m;-m (scalaire)
 * y   : adresse de dpart du vecteur de sortie (+1;-1)
 * sorties :
 * q   : adresse de dpart du vecteur de sortie de l'erreur de quantification
 */

void dsm1_c(int *n,double *m,double *u,double *e,double *z,double *y,double *q)
{
 /*dclaration*/
 int i;

 for(i=0;i<(*n);i++)
 {
  /*Calcul de l'intgrale du signal d'erreur*/
  *e+=u[i]-(*z);

  /*Ralisation de la comparaison de signe*/
  if((*e)>0) y[i]=1;
  else y[i]=-1;

  /*mise en mmoire de la sortie*/
  *z = *m*y[i];

  /*Calcul du bruit de quantification*/
  q[i]=(*z)-(*e);
 }
 return;
}
