/* dsm2_c subroutine
 * Second order Delta-Sigma Modulator
 * IRCOM GROUP - Author : A.Layec
 *
 * Copyright (C) 2007 Alan Layec
 *
 * This file is part of modnumlib.
 *
 * modnumlib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * modnumlib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with modnumlib; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

/* REVISION HISTORY :
 * $Log$
 */

#include "modnum_lib.h"

/* dsm2_c routine de calcul d'un modulateur sigma-delta du 2eme ordre
 *
 * entres :
 * n   : longueur du vecteur d'entre (scalaire)
 * m   : gain du modulateur (scalaire)
 * u   : adresse de dpart du vecteur  convertir
 * entres/sorties 
 * e   : intgral du signal d'erreur du dernier lment (vecteur)
 *       e[0]     : modulateur 1
 *       e[1]   : modulateur 2
 * z   : etat de sortie du dernier lment +m;-m (scalaire)
 *       z[0]     : modulateur 1
 *       z[1]     : modulateur 2
 *       z[2]     : etat mmoire du dsm2
 * y   : adresse de dpart du vecteur de sortie (+1;-1)
 * q   : adresse de dpart du vecteur de sortie de l'erreur de quantification
 * w   : adresse de dpart du vecteur de travail
 *
 * dpendances :
 * dsm1_c
 */

void dsm2_c(int *n,double *m,double *u,double *e,double *z,double *y,double *q,double *w)
{
 /*dclaration*/
 int i;

 /*Appel dsm1*/
 dsm1_c(n,m,&u[0],&e[0],&z[0],&y[0],&q[0]);

 /*Appel dsm1*/
 dsm1_c(n,m,&q[0],&e[1],&z[1],&w[0],&q[0]);

 /*ralise opration sur bruit*/
 for(i=0;i<(*n);i++)
 {
  y[i]=(y[i]+z[2]-w[i]);
  /*mise en mmoire de l'etat mmoire du dsm2*/
  z[2]=w[i];
 }
 return;
}
