/* comp Scicos sign comparison block
 * Type 4 simulation function - scilab-3.0
 * IRCOM GROUP - Author : A.Layec
 */

/* REVISION HISTORY :
 * $Log$
 */

#include "modnum_lib.h"
#include "scicos_block.h"

/* Cette fonction de simulation realise la comparaison de signe
 * du vecteur d'entre. Le vecteur de sortie prend les valeurs
 * +- ampl suivant le signe du vecteur d'entre.
 * Si le paramtre rpar est un vecteur on appelle compv_c
 * si c'est un scalaire on appelle comp_c.
 *
 * entre rgulire : u[0..nu-1] vecteur d'entre
 * sortie rgulire : y[0..ny-1] vecteur de sortie
 * entre vnementielle : Heritage ou explicite
 * sortie vnementeille : nant
 *
 * paramtre entier : nant
 * paramtre rel : rpar[0] ou rpar[0..nu-1] amplitude de sortie
 */

/*
 * compv_c routine de calcul de comparaison de signe
 *
 * Entres :
 * n    : taille des vecteurs
 * amp  : amplitude des sorties (vecteur)
 * u    : vecteur d'entre
 * Sorties :
 * y   : vecteur de sortie
 */
void compv_c(int *n,double *ampl,double *u,double *y)
{
 int i;

 for(i=0;i<(*n);i++)
 {
  if(u[i]>=0) y[i]=ampl[i];
  else y[i]=-ampl[i];
 }
 return;
}

/*Prototype*/
void comp(scicos_block *block,int flag)
{
 /*dclaration*/
  double *u,*y;

  /*rcupration des adresses des ports rguliers*/
  u=(double *)block->inptr[0];
  y=(double *)block->outptr[0];

  if(flag==1)
  {
   if (block->nrpar==1)
    /*Appel comp_c*/
    comp_c(&block->insz[0],&block->rpar[0],&u[0],&y[0]);
   else
    /*Appel compv_c*/
    compv_c(&block->insz[0],&block->rpar[0],&u[0],&y[0]);
  }
}
