/* pfdt Scicos Phase Frequency Detector block including 
 * Phase/Frequency Comparator with delay element for the RAZ of flip-flop
 * and charpe pump
 * Type 4 simulation function ver 1.0 - scilab-3.0
 * 13 janvier 2004 - IRCOM GROUP - Author : A.Layec
 */

/* REVISION HISTORY :
 * $Log$
 */

#include "modnum_lib.h"
#include "scicos_block.h"

/* entres rgulires      : nant
 * sorties : y[0..ny-1]   : vecteur de la pompe de charge
 *
 * entres vnementielles : nev = 1 : entre d'horloge de mise  jour du cpf
 *                           nev = 2 : entre d'horloge du diviseur de retour
 *                          nev = 4 : entre d'horloge de RAZ
 * sortie vnementielles  : evout[0] : vnement de remise  zro
 * paramtres entiers : outsz[0]    : taille des vecteurs de la pompe de charge (ny)
 *                      ipar[0..ny] : type de bruit de la pompe de charge (typ_leak)
 *                                   0: pas de fuite
 *                                   1: fuite constante
 *                                   2: fuite bruit normal
 *
 * paramtres rels   : rpar[0..ny-1]      : retard des Remises A Zro
 *                      rpar[ny..2*ny-1]   : courant max de la pompe de charge
 *                      rpar[2*ny..3*ny-1] : courant de fuite moyen de la pompe de charge
 *                      rpar[3*ny..4*ny-1] : deviation du courant de fuite 
 *
 * Etats discrets     : z[0..ny-1],z[ny..2*ny-1]        : etats mmoires des bascules
 *                      z[2*ny..3*ny-1],z[3*ny..4*ny-1] : etats de sorties des bascules
 *                      z[4*ny..5*ny-1]  : etat du comparateur (0:activ,1:dsactiv)
 */
void pfdt(scicos_block *block,int flag)
{
 /*dclaration*/
 int nev;
 int ny;
 double *y;
 int typ_leak;
 double *Io,*Ileak_d,*Ileak_m;
 double *delay;

 /*rcupration des adresses*/
 y=(double *)block->outptr[0];
 nev=block->nevprt;

 /*rcupration des paramtres*/
 ny=block->outsz[0];
 typ_leak=block->ipar[0];
 delay=&block->rpar[0];
 Io=&block->rpar[ny];
 Ileak_m=&block->rpar[2*ny];
 Ileak_d=&block->rpar[3*ny];

 /*Appel cpft*/
 cpft_c(&ny,&nev,&flag,&delay[0],&block->z[0],&block->z[ny],&block->evout[0],&block->z[2*ny],&block->z[3*ny],&block->z[4*ny]);

 if(flag==1)
 {
  /*Appel chargepump_c*/
   chargepump_c(&ny,&block->z[2*ny],&block->z[3*ny],&Io[0],&typ_leak,&Ileak_m[0],&Ileak_d[0],&y[0]);
  }
}
